@@ -76,7 +76,9 @@
 #include <stdarg.h>
 #include <errno.h>
 #include <time.h>
+#ifndef WIN32
 #include <sys/time.h>
+#endif
 #include <sys/stat.h>
 
 /* OpenSSL headers */
@@ -262,7 +264,11 @@
 /*
  * Support for MM library
  */
+#ifndef WIN32
 #define SSL_MM_FILE_MODE ( S_IRUSR|S_IWUSR )
+#else
+#define SSL_MM_FILE_MODE ( _S_IREAD|_S_IWRITE )
+#endif
 
 /*
  * Support for DBM library
@@ -285,8 +291,13 @@
 #define ssl_dbm_nextkey  sdbm_nextkey
 #define SSL_DBM_FILE_SUFFIX_DIR ".dir"
 #define SSL_DBM_FILE_SUFFIX_PAG ".pag"
+#else /* !SSL_USE_SDBM */
+#if defined(__GLIBC__) && defined(__GLIBC_MINOR__) \
+    && __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 1
+#include <db1/ndbm.h>
 #else
 #include <ndbm.h>
+#endif
 #define ssl_dbm_open     dbm_open
 #define ssl_dbm_close    dbm_close
 #define ssl_dbm_store    dbm_store
@@ -294,14 +305,17 @@
 #define ssl_dbm_delete   dbm_delete
 #define ssl_dbm_firstkey dbm_firstkey
 #define ssl_dbm_nextkey  dbm_nextkey
-#if defined(__FreeBSD__) || (defined(DB_LOCK) && defined(DB_SHMEM))
+#if defined(DBM_SUFFIX)
+#define SSL_DBM_FILE_SUFFIX_DIR DBM_SUFFIX
+#define SSL_DBM_FILE_SUFFIX_PAG DBM_SUFFIX
+#elif defined(__FreeBSD__) || (defined(DB_LOCK) && defined(DB_SHMEM))
 #define SSL_DBM_FILE_SUFFIX_DIR ".db"
 #define SSL_DBM_FILE_SUFFIX_PAG ".db"
 #else
 #define SSL_DBM_FILE_SUFFIX_DIR ".dir"
 #define SSL_DBM_FILE_SUFFIX_PAG ".pag"
 #endif
-#endif
+#endif /* !SSL_USE_SDBM */
 
 /*
  * Check for OpenSSL version and whether
