@@ -638,6 +638,7 @@ const char *ssl_cmd_SSLSessionCache(
     const char *err;
     SSLModConfigRec *mc = myModConfig();
     char *cp, *cp2;
+    int maxsize;
 
     if ((err = ap_check_cmd_context(cmd, GLOBAL_ONLY)) != NULL)
         return err;
@@ -667,7 +668,11 @@ const char *ssl_cmd_SSLSessionCache(
             *cp2 = NUL;
             mc->nSessionCacheDataSize = atoi(cp);
             if (mc->nSessionCacheDataSize <= 8192)
-                return "SSLSessionCache: Invalid argument: size has to be >= 8192";
+                return "SSLSessionCache: Invalid argument: size has to be >= 8192 bytes";
+            maxsize = ap_mm_core_maxsegsize();
+            if (mc->nSessionCacheDataSize >= maxsize)
+                return ap_psprintf(cmd->pool, "SSLSessionCache: Invalid argument: "
+                                   "size has to be < %d bytes on this platform", maxsize);
         }
     }
 	else
