@@ -309,15 +309,15 @@ void ssl_scache_dbm_store(server_rec *s, ssl_scinfo_t *SCI)
     datum dbmval;
 
     /* create DBM key */
-    dbmkey.dptr  = SCI->ucaKey;
+    dbmkey.dptr  = (char *)(SCI->ucaKey);
     dbmkey.dsize = SCI->nKey;
 
     /* create DBM value */
     dbmval.dsize = sizeof(time_t)+SCI->nData;
-    dbmval.dptr  = (UCHAR *)malloc(dbmval.dsize);
+    dbmval.dptr  = (char *)malloc(dbmval.dsize);
     if (dbmval.dptr == NULL)
         return;
-    memcpy(dbmval.dptr, &SCI->tExpiresAt, sizeof(time_t));
+    memcpy((char *)dbmval.dptr, &SCI->tExpiresAt, sizeof(time_t));
     memcpy((char *)dbmval.dptr+sizeof(time_t), SCI->ucaData, SCI->nData);
 
     /* and store it to the DBM file */
@@ -353,7 +353,7 @@ void ssl_scache_dbm_retrieve(server_rec *s, ssl_scinfo_t *SCI)
     SCI->tExpiresAt = 0;
 
     /* create DBM key and values */
-    dbmkey.dptr  = SCI->ucaKey;
+    dbmkey.dptr  = (char *)(SCI->ucaKey);
     dbmkey.dsize = SCI->nKey;
 
     /* and fetch it from the DBM file */
@@ -394,7 +394,7 @@ void ssl_scache_dbm_remove(server_rec *s, ssl_scinfo_t *SCI)
     datum dbmkey;
 
     /* create DBM key and values */
-    dbmkey.dptr  = SCI->ucaKey;
+    dbmkey.dptr  = (char *)(SCI->ucaKey);
     dbmkey.dsize = SCI->nKey;
 
     /* and delete it from the DBM file */
@@ -482,7 +482,8 @@ static void *ssl_scache_shm_realloc(void *ptr, size_t size)
 static void ssl_scache_shm_free(void *ptr)
 {
     SSLModConfigRec *mc = myModConfig();
-    return ap_mm_free(mc->pSessionCacheDataMM, ptr);
+    ap_mm_free(mc->pSessionCacheDataMM, ptr);
+    return;
 }
 
 /*
